﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using ShoeStore.Entities;
using ShoeStore.Entities.Enums;
using ShoeStore.Repositories;

namespace ShoeStore.Forms
{
    public partial class FormFactory : Form
    {
        private readonly IFactoryRepository _factoryRepository;
        private int? _factoryId;
        public int Id
        {
            set
            {
                try
                {
                    var factory =
                    _factoryRepository.ReadFactoryById(value);
                    if (factory == null)
                    {
                        throw new
                        InvalidDataException(nameof(factory));
                    }
                    textBoxFactoryName.Text = factory.FactoryName;

                    comboBoxManufacturer.SelectedItem =
                    factory.Manufacturer;
                    _factoryId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }
        public FormFactory(IFactoryRepository factoryRepository)
        {
            InitializeComponent();
            _factoryRepository = factoryRepository ??
            throw new
            ArgumentNullException(nameof(factoryRepository));
            comboBoxManufacturer.DataSource =
            Enum.GetValues(typeof(Manufacturer));
        }
        private void ButtonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxFactoryName.Text) || comboBoxManufacturer.SelectedIndex < 1)
                {
                    throw new Exception("Имеются незаполненные поля");
                }
                if (_factoryId.HasValue)
                {
                    _factoryRepository.UpdateFactory(CreateFactory(_factoryId.Value));
                }
                else
                {
                    _factoryRepository.CreateFactory(CreateFactory(0));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении",
                MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void ButtonCancel_Click(object sender, EventArgs e) =>
        Close();
        private Factory CreateFactory(int id) =>
        Factory.CreateEntity(id, textBoxFactoryName.Text, (Manufacturer)comboBoxManufacturer.SelectedItem!);
        private void FormFactory_Load(object sender, EventArgs e)
        {

        }

        
    }
}
