﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Microsoft.VisualBasic.FileIO;
using ShoeStore.Entities;
using ShoeStore.Entities.Enums;
using ShoeStore.Repositories;

namespace ShoeStore.Forms
{
    public partial class FormShoes : Form
    {
        private readonly IShoesRepository _shoesRepository;
        private int? _shoesId;
        public int Id
        {
            set
            {
                try
                {
                    var shoes = _shoesRepository.ReadShoesById(value);
                    if (shoes == null)
                    {
                        throw new
                        InvalidDataException(nameof(shoes));
                    }
                    foreach (ShoesType elem in
                    Enum.GetValues(typeof(ShoesType)))
                    {
                        if ((elem & shoes.ShoesType) != 0)
                        {
                            checkedListBoxShoesType.SetItemChecked(checkedListBoxShoesType.Items.IndexOf(
                            elem), true);
                        }
                    }
                    textBoxName.Text = shoes.Name;
                    textBoxDescription.Text = shoes.Description;
                    _shoesId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }
        public FormShoes(IShoesRepository shoesRepository)
        {
            InitializeComponent();
            _shoesRepository = shoesRepository ??
            throw new ArgumentNullException(nameof(shoesRepository));
            foreach (var elem in Enum.GetValues(typeof(ShoesType)))
            {
                checkedListBoxShoesType.Items.Add(elem);
            }
        }
        private void ButtonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxName.Text) ||
                string.IsNullOrWhiteSpace(textBoxDescription.Text) ||
                checkedListBoxShoesType.CheckedItems.Count == 0)
                {
                    throw new Exception("Имеются незаполненные поля");
                }
                if (_shoesId.HasValue)
                {
                    _shoesRepository.UpdateShoes(CreateShoes(_shoesId.Value));
                }
                else
                {
                    _shoesRepository.CreateShoes(CreateShoes(0));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении",
                MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void ButtonCancel_Click(object sender, EventArgs e) =>
        Close();
        private Shoes CreateShoes(int id)
        {
            ShoesType shoesType = ShoesType.None;
            foreach (var elem in checkedListBoxShoesType.CheckedItems)
            {
                shoesType |= (ShoesType)elem;
            }
            return Shoes.CreateEntity(id, shoesType, textBoxName.Text,
            textBoxDescription.Text);
        }


        private void FormShoes_Load(object sender, EventArgs e)
        {

        }

        private void label3_Click(object sender, EventArgs e)
        {

        }

        private void ButtonCancel_Click_1(object sender, EventArgs e)
        {

        }
    }
}
