﻿using ShoeStore.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Unity;

namespace ShoeStore.Forms
{
    public partial class FormShoesReplenishments : Form
    {
        private readonly IUnityContainer _container;
        private readonly IShoesReplenishmentRepository
        _shoesReplenishmentRepository;
        public FormShoesReplenishments(IUnityContainer container,
        IShoesReplenishmentRepository shoesReplenishmentRepository)
        {
            InitializeComponent();
            _container = container ??
            throw new ArgumentNullException(nameof(container));
            _shoesReplenishmentRepository = shoesReplenishmentRepository ??
            throw new
            ArgumentNullException(nameof(shoesReplenishmentRepository));
        }
        private void FormShoesReplenishments_Load(object sender, EventArgs e)
        {
            try
            {
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при загрузке",
                MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void ButtonAdd_Click(object sender, EventArgs e)
        {
            try
            {
                _container.Resolve<FormShoesReplenishment>().ShowDialog();
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при добавлении",
                MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void ButtonDel_Click(object sender, EventArgs e)
        {
            if (!TryGetIdentifierFromSelectedRow(out var findId))
            {
                return;
            }
            if (MessageBox.Show("Удалить запись?", "Удаление",
            MessageBoxButtons.YesNo) != DialogResult.Yes)
            {
                return;
            }
            try
            {
                _shoesReplenishmentRepository.DeleteShoesReplenishment(findId);
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при удалении",
                MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void LoadList() => dataGridViewData.DataSource =
        _shoesReplenishmentRepository.ReadShoesReplenishment();
        private bool TryGetIdentifierFromSelectedRow(out int id)
        {
            id = 0;
            if (dataGridViewData.SelectedRows.Count < 1)
            {
                MessageBox.Show("Нет выбранной записи", "Ошибка",
                MessageBoxButtons.OK, MessageBoxIcon.Error);
                return false;
            }
            id =
            Convert.ToInt32(dataGridViewData.SelectedRows[0].Cells["Id"].Value);
            return true;
        }
        private void dataGridViewData_CellContentClick(object sender, DataGridViewCellEventArgs e)
        {
            throw new NotImplementedException();
        }

        
    }

}
